<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>FeatherNotes::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="171"/>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::ColorLabel</name>
    <message>
        <location filename="../../colorLabel.cpp" line="31"/>
        <source>Click to change color.</source>
        <translation>Rengi değiştirmek için tıklayın.</translation>
    </message>
    <message>
        <location filename="../../colorLabel.cpp" line="53"/>
        <source>Select Color</source>
        <translation>Renk Seç</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::FN</name>
    <message>
        <location filename="../../fn.ui" line="14"/>
        <source>FeatherNotes</source>
        <translation>FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="65"/>
        <source>Next (F3)</source>
        <translation>İleri (F3)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="68"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="81"/>
        <source>Previous (F4)</source>
        <translation>Önceki (F4)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="84"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="100"/>
        <source>Search...</source>
        <translation>Arama...</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="115"/>
        <source>Search only in names (Ctrl+Shift+F7)</source>
        <translation>Yalnızca adlarda arama yapın (Ctrl+Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="118"/>
        <source>Ctrl+Shift+F7</source>
        <translation>Ctrl+Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="128"/>
        <source>Search only in tags (Shift+F7)</source>
        <translation>Sadece etiketlerde arama yapın (Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="131"/>
        <source>Shift+F7</source>
        <translation>Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="144"/>
        <source>Search in all nodes (F7)</source>
        <translation>Tüm düğümlerde arama (F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="147"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="186"/>
        <source>Whole Word (F6)</source>
        <translation>Tüm Kelime (F6)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="189"/>
        <source>Whole Word</source>
        <translation>Tüm Kelime</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="192"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="167"/>
        <source>Match Case (F5)</source>
        <translation>Match Durumu (F5)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="170"/>
        <source>Match Case</source>
        <translation>Match Durumu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="173"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="219"/>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="223"/>
        <source>Recenl&amp;y Opened</source>
        <translation>&amp;Son Açılan</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="245"/>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenleme</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="264"/>
        <source>For&amp;mat</source>
        <translation>&amp;Biçim</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="296"/>
        <source>&amp;Tree</source>
        <translation>&amp;Ağaç</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="320"/>
        <source>&amp;Options</source>
        <translation>&amp;Seçenekler</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="334"/>
        <source>&amp;Search</source>
        <translation>&amp;Arama</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="341"/>
        <location filename="../../fn.ui" line="987"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="436"/>
        <source>Find:</source>
        <translation>&amp;Bulmak:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="443"/>
        <source>Replace with:</source>
        <translation>Şununla değiştir:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="456"/>
        <source>To be replaced</source>
        <translation>Değiştirilecek</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="469"/>
        <source>Replacing text</source>
        <translation>Metni Değiştirme</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="479"/>
        <source>Previous (F9)</source>
        <translation>Önceki (F9)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="482"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="495"/>
        <source>Next (F8)</source>
        <translation>İleri (F8)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="498"/>
        <source>F8</source>
        <translation>F8</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="511"/>
        <source>Replace all (F10)</source>
        <translation>Tümünü değiştir (F10)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="514"/>
        <source>F10</source>
        <translation>F10</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="531"/>
        <source>&amp;Save</source>
        <translation>&amp;Kaydet</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="534"/>
        <location filename="../../fn.cpp" line="1018"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="537"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="542"/>
        <location filename="../../fn.cpp" line="678"/>
        <source>&amp;Open</source>
        <translation>&amp;Aç</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="545"/>
        <source>Open a file</source>
        <translation>&amp;Bir dosya aç</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="548"/>
        <source>Ctrl+O</source>
        <translation>Crtl+O</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="556"/>
        <source>&amp;Undo</source>
        <translation>&amp;Açmak</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="559"/>
        <source>Undo</source>
        <translation>Açmak</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="562"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="570"/>
        <source>&amp;Redo</source>
        <translation>&amp;Yinelemek</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="573"/>
        <source>Redo</source>
        <translation>Yinelemek</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="576"/>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="584"/>
        <source>&amp;Find</source>
        <translation>&amp;Bulmak</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="587"/>
        <source>Show/hide searchbar</source>
        <translation>Arama çubuğunu Göster/Gizle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="590"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="598"/>
        <source>&amp;Clear All Formats</source>
        <translation>&amp; Tüm Biçimleri Temizle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="601"/>
        <source>Clear all formats</source>
        <translation>Tüm Biçimleri Temizle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="604"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="615"/>
        <source>&amp;Bold</source>
        <translation>&amp;Kalın</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="618"/>
        <source>Bold</source>
        <translation>Kalın</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="621"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="632"/>
        <source>&amp;Italic</source>
        <translation>&amp;İtalik</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="635"/>
        <source>Italic</source>
        <translation>İtalik</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="638"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+İ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="649"/>
        <source>&amp;Underline</source>
        <translation>&amp;Altı çizili</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="652"/>
        <source>Underline</source>
        <translation>Altı çizili</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="655"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="666"/>
        <source>&amp;Strike Through</source>
        <translation>&amp;Üstü çizili</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="669"/>
        <source>Strike through</source>
        <translation>Üstü çizili</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="672"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="680"/>
        <source>Te&amp;xt Color</source>
        <translation>&amp; Yazı Rengi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="683"/>
        <source>Text color</source>
        <translation>Yazı Rengi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="686"/>
        <source>Alt+Shift+T</source>
        <translation>Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="694"/>
        <source>Back&amp;ground Color</source>
        <translation>&amp;Arkaplan Rengi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="697"/>
        <source>Background color</source>
        <translation>Arkaplan Rengi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="700"/>
        <source>Alt+Shift+B</source>
        <translation>Alt+Shift+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="705"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="710"/>
        <location filename="../../fn.cpp" line="677"/>
        <source>&amp;New Note</source>
        <translation>&amp;Yeni Not</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="713"/>
        <source>Ctrl+Alt+Shift+N</source>
        <translation>Ctrl+Alt+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="721"/>
        <source>Save &amp;As</source>
        <translation>&amp;Farklı Kaydet</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="724"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="732"/>
        <source>&amp;Print</source>
        <translation>&amp;Yazıcı</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="735"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="743"/>
        <source>P&amp;rint with Sub-Nodes</source>
        <translation>&amp;Alt Düğümlerle Yazdır</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="751"/>
        <source>Set Pass&amp;word</source>
        <translation>&amp;Şifrelemek</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="756"/>
        <location filename="../../fn.cpp" line="680"/>
        <source>&amp;Quit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="759"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="767"/>
        <source>&amp;Cut</source>
        <translation>&amp;Kes</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="770"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="778"/>
        <source>C&amp;opy</source>
        <translation>&amp;Copy</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="781"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="789"/>
        <source>&amp;Paste</source>
        <translation>&amp;Yapıştır</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="792"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="800"/>
        <source>&amp;Delete</source>
        <translation>&amp;Sil</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="808"/>
        <source>&amp;Select All</source>
        <translation>&amp;Hepsini Seç</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="811"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="819"/>
        <source>E&amp;mbed Image</source>
        <translation>&amp;Görüntü Eklemek</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="822"/>
        <location filename="../../fn.cpp" line="4414"/>
        <source>Embed Image</source>
        <translation>Görüntü Eklemek</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="825"/>
        <source>Ctrl+Alt+Shift+I</source>
        <translation>Ctrl+Alt+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="833"/>
        <source>E&amp;xpand All</source>
        <translation>&amp;Tümünü Genişlet</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="836"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Aşağı Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="844"/>
        <source>Collap&amp;se All</source>
        <translation>&amp;Tümünü Daralt</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="847"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="855"/>
        <source>&amp;Append Sibling</source>
        <translation>&amp;Kardeş Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="858"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="866"/>
        <source>Append &amp;Child</source>
        <translation>&amp;Çocuk Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="869"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="877"/>
        <source>&amp;Delete Node</source>
        <translation>&amp;Düğümü Sil</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="880"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="888"/>
        <source>Move &amp;Up</source>
        <translation>&amp;Yukarı Taşı</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="891"/>
        <source>Alt+Up</source>
        <translation>Alt+Yukarı Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="899"/>
        <source>Move Do&amp;wn</source>
        <translation>&amp;Aşağı Taşı</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="902"/>
        <source>Alt+Down</source>
        <translation>Alt+Aşağı Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="910"/>
        <source>Re&amp;name Node</source>
        <translation>&amp;Düğümü Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="913"/>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="918"/>
        <source>Tree Pr&amp;operties</source>
        <translation>&amp;Ağaç Özellikleri</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="921"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="929"/>
        <source>Document &amp;Font</source>
        <translation>&amp;Belge Yazı Tipi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="943"/>
        <source>&amp;Wrap Lines</source>
        <translation>&amp;Çizgileri Sarın</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="946"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="960"/>
        <source>&amp;Auto-Indentation</source>
        <translation>&amp;Otomatik Girinti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="963"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="968"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Tercih</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="971"/>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="979"/>
        <source>Find and &amp;Replace</source>
        <translation>&amp;Bul ve Değiştir</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="982"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="990"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="995"/>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1003"/>
        <source>Pr&amp;int All Nodes</source>
        <translation>&amp;Tüm Düğümleri Yazdır</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1014"/>
        <source>Superscrip&amp;t</source>
        <translation>&amp;Üst simge</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1017"/>
        <source>Superscript</source>
        <translation>Üst simge</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1020"/>
        <source>Alt+Shift+U</source>
        <translation>Alt+Shift+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1031"/>
        <source>Subscri&amp;pt</source>
        <translation>&amp;Alt simge</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1034"/>
        <source>Subscript</source>
        <translation>Alt simge</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1037"/>
        <source>Alt+Shift+S</source>
        <translation>Alt+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1048"/>
        <source>C&amp;enter</source>
        <translation>&amp;Orta</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1051"/>
        <source>Align center</source>
        <translation>Merkezi Hizala</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1054"/>
        <source>Alt+Shift+Down</source>
        <translation>Alt+Shift+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1065"/>
        <location filename="../../fn.cpp" line="2217"/>
        <source>&amp;Right</source>
        <translation>&amp;Sağ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1068"/>
        <source>Align right</source>
        <translation>Sağa Hizala</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1071"/>
        <source>Alt+Shift+Right</source>
        <translation>Alt+Shift+Sağ Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1082"/>
        <location filename="../../fn.cpp" line="2211"/>
        <source>&amp;Left</source>
        <translation>&amp;Sol</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1085"/>
        <source>Align left</source>
        <translation>Sola Hizala</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1088"/>
        <source>Alt+Shift+Left</source>
        <translation>Alt+Shift+Sol Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1099"/>
        <source>&amp;Justify</source>
        <translation>&amp;Yasla</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1102"/>
        <source>Justify</source>
        <translation>Yasla</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1105"/>
        <source>Alt+Shift+Up</source>
        <translation>Alt+Shift+Yukarı Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1113"/>
        <source>&amp;Prepend Sibling</source>
        <translation>&amp;Kardeş Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1116"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1124"/>
        <source>Move &amp;Left</source>
        <translation>&amp;Sola Taşı</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1127"/>
        <source>Alt+Left</source>
        <translation>Alt+Sol Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1135"/>
        <source>Move &amp;Right</source>
        <translation>&amp;Sağa Taşı</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1138"/>
        <source>Alt+Right</source>
        <translation>Alt+Sağ Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1146"/>
        <source>h&amp;2</source>
        <translation>&amp;h2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1149"/>
        <source>Header 2</source>
        <translation>Başlık 2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1152"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1160"/>
        <source>h&amp;1</source>
        <translation>&amp;h1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1163"/>
        <source>Header 1</source>
        <translation>Başlık 1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1166"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1174"/>
        <source>h&amp;3</source>
        <translation>&amp;h3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1177"/>
        <source>Header 3</source>
        <translation>Başlık 3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1180"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1188"/>
        <source>&amp;Node Font</source>
        <translation>&amp;Düğüm Yazı Tipi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1191"/>
        <source>Node Font</source>
        <translation>Düğüm Yazı Tipi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1196"/>
        <source>Scale I&amp;mage(s)</source>
        <translation>&amp;Ölçek görüntü(ler)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1204"/>
        <source>Paste &amp;HTML</source>
        <translation>&amp;HTML Yapıştır</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1207"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1215"/>
        <source>&amp;Tags</source>
        <translation>&amp;Etiketler</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1218"/>
        <source>Ctrl+Shift+T</source>
        <translation>Ctrl+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1226"/>
        <source>Insert Lin&amp;k</source>
        <translation>&amp;Bağlantı Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1229"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1234"/>
        <source>C&amp;opy Link</source>
        <translation>&amp;Bağlantıyı Kopyala</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1242"/>
        <source>I&amp;nsert Table</source>
        <translation>&amp;Tablo Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1245"/>
        <source>Ctrl+Alt+Shift+T</source>
        <translation>Ctrl+Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1250"/>
        <source>Append Row</source>
        <translation>Satır Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1255"/>
        <source>Delete Row</source>
        <translation>Satırı Sil</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1260"/>
        <source>Append Column</source>
        <translation>Sütun Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1265"/>
        <source>Delete Column</source>
        <translation>Sütun Sil</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1270"/>
        <source>Merge Cells</source>
        <translation>Hücreleri Birleştir</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1275"/>
        <source>Prepend Row</source>
        <translation>Satır Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1280"/>
        <source>Prepend Column</source>
        <translation>Sütun Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1288"/>
        <source>Export &amp;HTML</source>
        <translation>&amp;HTML&apos;yi Dışa Aktar</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1293"/>
        <source>Save Ima&amp;ge(s)</source>
        <translation>&amp;Görüntüleri Kaydet</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1304"/>
        <source>RTL</source>
        <translation>RTL</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1307"/>
        <source>Ctrl+Alt+Shift+Left</source>
        <translation>Ctrl+Alt+Shift+Sol Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1318"/>
        <source>LTR</source>
        <translation>LTR</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1321"/>
        <source>Ctrl+Alt+Shift+Right</source>
        <translation>Ctrl+Alt+Shift+Sağ Yön Tuşu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1326"/>
        <location filename="../../fn.ui" line="1329"/>
        <source>Menu</source>
        <translation>Menü</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1337"/>
        <source>Node &amp;Icon</source>
        <translation>&amp;Düğüm Simgesi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1340"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1345"/>
        <location filename="../../fn.ui" line="1348"/>
        <source>Check Spelling</source>
        <translation>Yazım Denetimi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1351"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1356"/>
        <source>Document &amp;Colors</source>
        <translation>&amp;Belge Renkleri</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1364"/>
        <location filename="../../fn.ui" line="1367"/>
        <source>Paste Date and Time</source>
        <translation>Tarih ve saati yapıştır</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1372"/>
        <source>&amp;Clear</source>
        <translation>&amp;Açık</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3001"/>
        <source>Node Icon</source>
        <translation>Düğüm Simgesi</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="674"/>
        <source>&amp;Raise/Hide</source>
        <translation>&amp;Kaldır/Gizle</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="914"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Yeni Not mu?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="915"/>
        <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Gerçekten bu belgeyi bırakmak istiyor musunuz&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;ve boş bir tane mi yaratalım?&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="918"/>
        <location filename="../../fn.cpp" line="2832"/>
        <location filename="../../fn.cpp" line="4777"/>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="919"/>
        <location filename="../../fn.cpp" line="2833"/>
        <location filename="../../fn.cpp" line="4778"/>
        <source>No</source>
        <translation>Hayır</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1010"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Değişiklikleri Kaydet?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1012"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Belge değiştirildi.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1014"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Belge kaldırıldı.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1019"/>
        <source>Discard changes</source>
        <translation>Değişiklikleri at</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1020"/>
        <location filename="../../fn.cpp" line="2950"/>
        <location filename="../../fn.cpp" line="3044"/>
        <location filename="../../fn.cpp" line="3317"/>
        <location filename="../../fn.cpp" line="4353"/>
        <location filename="../../fn.cpp" line="4438"/>
        <location filename="../../fn.cpp" line="4616"/>
        <location filename="../../fn.cpp" line="4879"/>
        <location filename="../../fn.cpp" line="5827"/>
        <location filename="../../fn.cpp" line="6106"/>
        <location filename="../../fn.cpp" line="6204"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1484"/>
        <source>Open file...</source>
        <translation>Dosya Aç...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1661"/>
        <location filename="../../fn.cpp" line="5953"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Kurtarılamaz!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3613"/>
        <source>Close</source>
        <translation>Kapatma</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1761"/>
        <location filename="../../fn.cpp" line="1784"/>
        <source>Save As...</source>
        <translation>Farklı Kaydet...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1486"/>
        <location filename="../../fn.cpp" line="1763"/>
        <location filename="../../fn.cpp" line="1786"/>
        <source>FeatherNotes documents</source>
        <translation>FeatherNotes belgeler</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1486"/>
        <location filename="../../fn.cpp" line="1763"/>
        <location filename="../../fn.cpp" line="1786"/>
        <location filename="../../fn.cpp" line="3033"/>
        <location filename="../../fn.cpp" line="4537"/>
        <location filename="../../fn.cpp" line="4808"/>
        <source>All Files</source>
        <translation>tüm dosyalar</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2829"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Bu düğüm silinsin mi?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2830"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;Uyarı!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;Bu eylem geri alınamaz.&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2936"/>
        <source>Tags</source>
        <translation>Etiketler</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2951"/>
        <location filename="../../fn.cpp" line="3045"/>
        <location filename="../../fn.cpp" line="3318"/>
        <location filename="../../fn.cpp" line="4355"/>
        <location filename="../../fn.cpp" line="4439"/>
        <location filename="../../fn.cpp" line="4617"/>
        <location filename="../../fn.cpp" line="4880"/>
        <location filename="../../fn.cpp" line="5829"/>
        <location filename="../../fn.cpp" line="6107"/>
        <location filename="../../fn.cpp" line="6205"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3033"/>
        <location filename="../../fn.cpp" line="4537"/>
        <location filename="../../fn.cpp" line="4808"/>
        <source>Image Files</source>
        <translation>Resim Dosyaları</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3125"/>
        <location filename="../../fn.cpp" line="3158"/>
        <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;Ana düğümler:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Bütün düğümler:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3131"/>
        <location filename="../../fn.cpp" line="3164"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
        <translation>&lt;b&gt;Not:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Ana düğümler::&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Bütün düğümler:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3600"/>
        <source>%1 Matches</source>
        <translation>%1 Eşleşme</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3602"/>
        <source>One Match</source>
        <translation>Bir eşleşme</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3604"/>
        <location filename="../../fn.cpp" line="3971"/>
        <source>No Match</source>
        <translation>Eşleşme yok</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3770"/>
        <location filename="../../fn.cpp" line="3823"/>
        <source>Replacement</source>
        <translation>Yedek</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4078"/>
        <source>No Replacement</source>
        <translation>Yedek yok</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4080"/>
        <source>One Replacement</source>
        <translation>Bir yedek</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4083"/>
        <source>%1 Replacements</source>
        <translation>%1 Yedekler</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4341"/>
        <source>Insert Link</source>
        <translation>Bağlantı Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6050"/>
        <source>HTML Files</source>
        <translation>HTML Dosyaları</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3009"/>
        <location filename="../../fn.cpp" line="4423"/>
        <source>Image path</source>
        <translation>Görüntü yolu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3013"/>
        <location filename="../../fn.cpp" line="4427"/>
        <source>Open image</source>
        <translation>Görüntü aç</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4435"/>
        <location filename="../../fn.cpp" line="4613"/>
        <source>Scaling percentage</source>
        <translation>Ölçekleme yüzdesi</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3031"/>
        <location filename="../../fn.cpp" line="4535"/>
        <source>Open Image...</source>
        <translation>Görüntü aç...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="649"/>
        <source>System tray is not available.
Please disable tray in Preferences.</source>
        <translation>Sistem çekmecesi mevcut değil.
Lütfen Tercihler&apos;den sistem çekmecesini kapatın.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="965"/>
        <source>New Node</source>
        <translation>Yeni düğüm</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1662"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Açılamaz!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1743"/>
        <location filename="../../fn.cpp" line="5668"/>
        <location filename="../../fn.cpp" line="5677"/>
        <location filename="../../fn.cpp" line="5816"/>
        <location filename="../../fn.cpp" line="6007"/>
        <location filename="../../fn.cpp" line="6016"/>
        <location filename="../../fn.cpp" line="6043"/>
        <source>Untitled</source>
        <translation>İsimsiz</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2210"/>
        <source>Align Table</source>
        <translation>Tabloyu Hizala</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2223"/>
        <source>&amp;Center</source>
        <translation>&amp;Orta</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2662"/>
        <source>Select Text Color</source>
        <translation>Metin rengini seç</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2694"/>
        <source>Select Background Color</source>
        <translation>Arkaplan rengini seç</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2828"/>
        <source>Deletion</source>
        <translation>Silme</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2946"/>
        <source>Tag(s) for this node</source>
        <translation>Bu düğüm için etiketler</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3202"/>
        <source>Select Document Font</source>
        <translation>Belge Yazı Tipini Seç</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3264"/>
        <source>Select Node Font</source>
        <translation>Düğüm Yazı Tipini Seçin</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3289"/>
        <source>Set Document Colors</source>
        <translation>Belge Renklerini Ayarlama</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3299"/>
        <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
        <translation>Bu renkler yeni düğümlere uygulanacaktır. &lt;br&gt; Mevcut düğümleri etkileyebilir veya etkilemeyebilir &lt;br&gt; ancak belgenin yeniden açılması önerilir.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3302"/>
        <source>Background color:</source>
        <translation>Arka plan rengi:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3308"/>
        <source>Text color:</source>
        <translation>Metin rengi:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4088"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation>İlk 1000 değiştirme vurgulanmıştır.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4430"/>
        <location filename="../../fn.cpp" line="4609"/>
        <source>Scale to</source>
        <translation>Ölçekle</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4434"/>
        <location filename="../../fn.cpp" line="4612"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4603"/>
        <source>Scale Image(s)</source>
        <translation>Resimleri Ölçekle</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4740"/>
        <source>untitled</source>
        <translation>başlıksız</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4772"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4773"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt; &lt;big&gt; Görüntü kaydedilemiyor! Yeniden denilsin mi? &lt;/big&gt; &lt;/b&gt; &lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4774"/>
        <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
&lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
        <translation>&lt;center&gt; Belki uygun bir uzantı seçmediniz &lt;/center&gt;
&lt;center&gt; veya yazma izniniz yok. &lt;/center&gt; &lt;p&gt; &lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4806"/>
        <source>Save Image As...</source>
        <translation>Görüntüyü Farklı Kaydet...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4861"/>
        <source>Insert Table</source>
        <translation>Tablo Ekle</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4867"/>
        <source>Rows:</source>
        <translation>Satırlar:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4873"/>
        <source>Columns:</source>
        <translation>Sütunlar:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5757"/>
        <source>Print Document</source>
        <translation>Belgeyi Yazdır</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5763"/>
        <source>Printing completed.</source>
        <translation>Baskı tamamlandı.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5765"/>
        <source>Printing in progress...</source>
        <translation>Yazdırma devam ediyor ...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5784"/>
        <source>Export HTML</source>
        <translation>HTML&apos;yi dışa aktar</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5789"/>
        <source>Export:</source>
        <translation>Dışa aktar:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5790"/>
        <source>&amp;Current node</source>
        <translation>&amp;Geçerli düğüm</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5792"/>
        <source>With all &amp;sub-nodes</source>
        <translation>Tüm &amp;alt düğümlerle</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5793"/>
        <source>&amp;All nodes</source>
        <translation>&amp;Tüm düğümler</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5805"/>
        <source>Output file:</source>
        <translation>Çıktı dosyası:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5824"/>
        <source>Select path</source>
        <translation>Yol seçin</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5865"/>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5866"/>
        <source>The file already exists.
Do you want to replace it?
</source>
        <translation>Dosya zaten var.
Değiştirmek istiyor musun?
</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6048"/>
        <source>Save HTML As...</source>
        <translation>HTML&apos;yi Farklı Kaydet...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6074"/>
        <source>Set Password</source>
        <translation>Şifreyi belirle</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6083"/>
        <source>Type password</source>
        <translation>Şifreyi yaz</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6095"/>
        <source>Retype password</source>
        <translation>Şifrenizi yeniden yazın</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6167"/>
        <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt; Parolalar farklıydı. Yeniden deneyin! &lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6187"/>
        <location filename="../../fn.cpp" line="6195"/>
        <source>Enter Password</source>
        <translation>Parolanı Gir</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6267"/>
        <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt; Yanlış şifre. Yeniden deneyin! &lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6309"/>
        <source>A lightweight notes manager</source>
        <translation>Hafif bir not yöneticisi</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6310"/>
        <source>based on Qt</source>
        <translation>Qt&apos;ye göre</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6311"/>
        <source>Author</source>
        <translation>Yazar</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6313"/>
        <location filename="../../fn.cpp" line="6314"/>
        <source>About FeatherNotes</source>
        <translation>Tüy Notları Hakkında</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6313"/>
        <source>Translators</source>
        <translation>Çevirmenler</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6497"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation>Tercihler → Metin → Yazım Denetimi&apos;ne bakın!</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6513"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation>Hunspell sözlüğü eklemeniz gerekiyor.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6518"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation>Hunspell sözlüğü mevcut değil.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6526"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation>Hunspell sözlüğüne bir ek dosyası eşlik etmez.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6544"/>
        <location filename="../../fn.cpp" line="6559"/>
        <location filename="../../fn.cpp" line="6571"/>
        <source>No misspelling from text cursor.</source>
        <translation>Metin imlecinden yanlış yazım yok.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6583"/>
        <source>Spell Checking</source>
        <translation>Yazım Denetimi</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6312"/>
        <source>aka.</source>
        <translation>diğer adıyla.</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="35"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Metni temizle (Ctrl + K)</translation>
    </message>
    <message>
        <location filename="../../lineedit.cpp" line="81"/>
        <source>Ctrl+K</source>
        <comment>Clear text</comment>
        <translation>Ctrl+K</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Tercihler</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="27"/>
        <source>Window</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="36"/>
        <source>Saves window size after closing
this dialog and also on exit.

Uncheck to set a fixed size!</source>
        <translation>Kapattıktan sonra pencere boyutunu kaydeder
bu iletişim kutusu ve ayrıca çıkışta.

Sabit bir boyut ayarlamak için işareti kaldırın!</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="42"/>
        <source>Remember window &amp;size</source>
        <translation>&amp;Pencere ve boyutu hatırla</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="51"/>
        <source>Start with this size: </source>
        <translation>Bu boyutla başlayın: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="58"/>
        <location filename="../../prefDialog.ui" line="72"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="97"/>
        <source>Saves tree width after closing
this dialog and also on exit.

Uncheck for a width ratio of 170/530.</source>
        <translation>Bu iletişim kutusunu kapattıktan sonra
ve ayrıca çıkışta ağaç genişliğini kaydeder.

170/530 genişlik oranının işaretini kaldırın.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="103"/>
        <source>Remember &amp;tree width</source>
        <translation>Ağaç genişliğini hatırla</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>Saves position after closing
this dialog and also on exit.

This may not work correctly
with some window managers.</source>
        <translation>Bu diyaloğu kapattıktan sonra ve
ayrıca çıkışta konumu kaydeder.

 Bu, bazı pencere yöneticileriyle
düzgün çalışmayabilir.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="117"/>
        <source>Save &amp;position</source>
        <translation>Kaydet ve konumlandır</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="124"/>
        <source>Decides whether a systray icon should be used.
If checked, the titlebar close button iconifies
the window to the systray instead of quitting.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Systray simgesinin kullanılıp kullanılmayacağına karar verir. İşaretlenirse, başlık çubuğu kapat düğmesi, çıkmak yerine pencereyi sistem tepsisine gösterir. Etkili olması için FeatherNotes&apos;un yeniden başlatılması gerekiyor.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="131"/>
        <source>Add to s&amp;ystray</source>
        <translation>&amp;Systray&apos;e ekle</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="156"/>
        <source>The command line option --tray
can be used instead of this.</source>
        <translation>Bunun yerine komut satırı seçeneği --tray kullanılabilir.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="160"/>
        <source>Start i&amp;conified to tray</source>
        <translation>Tepside simge haline getirilmeyi başlatın</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="169"/>
        <source>Merge the tree view with its surroundings?</source>
        <translation>Ağaç görünümü çevresiyle birleştirilsin mi?</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="172"/>
        <source>Transparent t&amp;ree view</source>
        <translation>Şeffaf ekran görünümü</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="179"/>
        <source>By default, the active widget style determines
the size of toolbar icons.</source>
        <translation>Varsayılan olarak, etkin pencere öğesi stili,
the size of toolbar icons.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="183"/>
        <source>Small toolbar icons</source>
        <translation>Küçük araç çubuğu simgeleri</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="190"/>
        <source>Do not show t&amp;oolbar</source>
        <translation>&amp;Toolbar&apos;ı gösterme</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="197"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation>Menü çubuğu gizlenmişse,
araç çubuğunda bir menü düğmesi görünür.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="201"/>
        <source>Do not show &amp;menubar</source>
        <translation>&amp;Menü çubuğunu gösterme</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="228"/>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="237"/>
        <source>&amp;Wrap lines by default</source>
        <translation>&amp;Varsayılan olarak satırları kaydır</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="244"/>
        <source>Auto-&amp;indent by default</source>
        <translation>&amp;Varsayılan olarak otomatik girinti</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="251"/>
        <source>This covers parentheses, braces, brackets and quotes.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Bu ayraçları, köşeli ve kaşlı ayraçları ve tırnak işaretlerini kapsar.

Etkili olması için FeatherNotes&apos;un yeniden başlatılması gerekiyor.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="256"/>
        <source>Auto-&amp;bracket</source>
        <translation>&amp;Otomatik parantez</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="263"/>
        <source>A triple period is replaced with an ellipsis,
a double hyphen with a long dash, etc. while
the user is typing and under proper circumstances.</source>
        <translation>Üç nokta bir üç nokta ile değiştirilir,
uzun tire içeren çift kısa çizgi vb.
kullanıcı yazıyor ve uygun koşullar altında.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>&amp;Replace some characters while typing</source>
        <translation>&amp;Yazarken bazı karakterleri değiştir</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="277"/>
        <location filename="../../prefDialog.ui" line="290"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation>Tarih ve saati yapıştırmak için kullanılır.
Sistem Varsayılanı için boş bırakın.

Bu iletişim penceresini kapattıktan sonra etkili olur.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="283"/>
        <source>Date and time format:</source>
        <translation>Tarih ve saat biçimi:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>&amp;Auto-save every</source>
        <translation>&amp;Her birini otomatik Kaydet</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="314"/>
        <source> minute(s)</source>
        <translation> dakika</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="348"/>
        <source>If this option is checked, the opened document will
be saved on exiting without prompt and without
showing a warning if saving is not possible.</source>
        <translation>Bu seçenek işaretlenirse, açılan belge
 istenmeden ve gerekmeden çıkarken kaydedilebilir
 kaydetme mümkün değilse bir uyarı gösteriliyor.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="353"/>
        <source>Save opened document on exiting</source>
        <translation>Açılan belgeyi çıkarken kaydet</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="376"/>
        <source>Spell Checking</source>
        <translation>Yazım Denetimi</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="384"/>
        <location filename="../../prefDialog.ui" line="396"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation>Hunspell sözlüğünün &quot;.dic&quot; ile biten bir adı vardır
ve yanında adı aynı ancak &quot;.aff&quot; ile biten olan
ek bir dosya olmalıdır.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="389"/>
        <source>Hunspell dictionary path:</source>
        <translation>Hunspell sözlük yolu:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="408"/>
        <location filename="../../pref.cpp" line="647"/>
        <source>Add dictionary...</source>
        <translation>Sözlük ekle ...</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Files</source>
        <translation>Dosyalar</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="452"/>
        <source>Start with the last opened file</source>
        <translation>Son açılan dosyayla başlayın</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="464"/>
        <source>Number of recent files:</source>
        <translation>Son dosya sayısı:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="496"/>
        <source>Open recent files separately</source>
        <translation>Son dosyaları ayrı olarak açın</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="503"/>
        <source>By default, all nodes are expanded on opening a document.</source>
        <translation>Varsayılan olarak, bir belge açıldığında tüm düğümler genişletilir.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="506"/>
        <source>Remember expanded states of nodes</source>
        <translation>Genişletilmiş düğüm durumlarını hatırla</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="530"/>
        <source>Shortcuts</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="549"/>
        <source>Action</source>
        <translation>İşlem</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="554"/>
        <source>Shortcut</source>
        <translation>Kısayol</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="562"/>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="340"/>
        <location filename="../../pref.cpp" line="520"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation>Uyarı: Belirsiz kısayol algılandı!</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="503"/>
        <source>The typed shortcut was reserved.</source>
        <translation>Yazılan kısayol rezerve edildi.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="618"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Değişikliklerin etkili olması için uygulamanın yeniden başlatılması gerekiyor.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="649"/>
        <source>Hunspell Dictionary Files</source>
        <translation>Hunspell Sözlük Dosyaları</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>Bilinmeyen kelime:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation>Sözlüğe Ekle</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>Şununla değiştir:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>Bir Kerelik Yoksay</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>Hepsini Yoksay</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>Bir Kerelik Düzelt</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation>Hepsini Düzelt</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::helpDialog</name>
    <message>
        <location filename="../../helpDialog.ui" line="14"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../domitem.cpp" line="100"/>
        <location filename="../../domitem.cpp" line="137"/>
        <source>New Node</source>
        <translation>Yeni Düğüm</translation>
    </message>
</context>
</TS>
